@@ -48,7 +48,7 @@ use PPIx::Regexp::Constant qw{
     @CARP_NOT
 };
 
-our $VERSION = '0.066';
+our $VERSION = '0.068';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -113,9 +113,12 @@ sub perl_version_introduced {
     }
 
     sub __no_explanation {
-##	my ( $self ) = @_;		# Invocant unused
-	my $msg = sprintf q<Unknown POSIX character class>;
-	return $msg;
+	my ( $self ) = @_;
+	local $_ = $self->content();
+	m/ \A \[ = ( . ) = \] \z /smx
+	    and return "POSIX Character Equivalent (to '$1'; " .
+		"unimplemented in Perl)";
+	return q<Unknown POSIX character class>;
     }
 
 }
@@ -153,7 +156,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -161,7 +164,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2019 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
